@@ -339,7 +339,7 @@ while test -n "$1" ; do
   package)	pkg ; STATUS=$? ;;
   pkg)		pkg ; STATUS=$? ;;
   mkpatch)	mkpatch ; STATUS=$? ;;
-    acceptpatch)	acceptpatch ; STATUS=$? ;;
+  acceptpatch)	acceptpatch ; STATUS=$? ;;
   src-package)	spkg ; STATUS=$? ;;
   spkg)		spkg ; STATUS=$? ;;
   finish)	finish ; STATUS=$? ;;
@@ -348,6 +348,12 @@ while test -n "$1" ; do
   all)		checksig && prep && conf && build && install && \
 		strip && pkg && spkg && finish ; \
 		STATUS=$? ;;
+  all_dev)	prep && conf && build && install && strip && pkg && spkg && \
+		check && checksig && \
+		echo "Depends on:" && depend && \
+		echo "File list:" && list && \
+		finish ; \
+		STATUS=$? ;;
   *) echo "Error: bad arguments" ; exit 1 ;;
   esac
   ( exit ${STATUS} ) || exit ${STATUS}
